@@ -2,6 +2,7 @@ import shutil
 from functools import lru_cache
 from os import PathLike
 from pathlib import Path
+from typing import Union
 
 from minio import Minio
 from minio.error import S3Error
@@ -28,7 +29,7 @@ class Client:
                 raise err
         return True
 
-    def put(self, cid: CID, input: str | PathLike[str], progress: Progress):
+    def put(self, cid: CID, input: Union[str, PathLike[str]], progress: Progress):
         if self.has(cid):
             progress.set_completed()
             return
@@ -36,7 +37,7 @@ class Client:
         file = str(Path(input).resolve())
         self._minio.fput_object(env.BLX_BUCKET, cid.hex(), file, progress=progress)
 
-    def get(self, cid: CID, output: str | PathLike[str], progress: Progress):
+    def get(self, cid: CID, output: Union[str, PathLike[str]], progress: Progress):
         if cache.has(cid):
             shutil.copyfile(cache.get(cid), output)
             progress.set_completed()
